@@ -1,6 +1,5 @@
-from .receivers import EasyRecListeners
-from .utils import get_gateway
-
+from easyrec.receivers import EasyRecListeners
+from easyrec.utils import get_gateway
 
 easyrec = get_gateway()
 listeners = EasyRecListeners(easyrec)
