@@ -1,7 +1,6 @@
 from django.conf import settings
 
-
-from .gateway import EasyRec, DummyRequests
+from easyrec.gateway import EasyRec, DummyRequests
 
 
 def get_gateway():
@@ -11,9 +10,8 @@ def get_gateway():
     if 'DUMMY' == endpoint:
         easyrec = EasyRec("http://DUMMY", '', '')
         easyrec._requests = DummyRequests()
-    else:
-        tenant_id = settings.EASYREC_TENANT_ID
-        api_key = settings.EASYREC_API_KEY
-        easyrec = EasyRec(endpoint, tenant_id, api_key)
+        return easyrec
 
-    return easyrec
+    tenant_id = settings.EASYREC_TENANT_ID
+    api_key = settings.EASYREC_API_KEY
+    return EasyRec(endpoint, tenant_id, api_key)
